@@ -1,13 +1,13 @@
 mod argument;
-mod callable;
 mod contract_trait;
 mod endpoint;
 mod method;
 mod payable;
+mod supertrait;
 
 pub use argument::*;
-pub use callable::*;
 pub use contract_trait::*;
 pub use endpoint::*;
 pub use method::*;
 pub use payable::*;
+pub use supertrait::*;
